Tree

Struct Tree 

pub struct Tree<H: Hash<Scalar>> { /* private fields */ }
A Merkle tree whose leaves are multiple polynomial evaluations.

The tree has N leaf in total, with N being the size of the extended domain, and each leaf has K polynomial evaluations, with K being the number of committed polynomials.

The internal nodes are single hashes.

Implementations

Source

impl<H: Hash<Scalar>> Tree<H>

pub fn from_leaves(leaves: Vec<Vec<Scalar>>) -> Self

Constructs a Merkle tree from a matrix of polynomial evaluations.

More than one polynomial can be batched in the same tree because we our tree leaves are vectors rather than single scalars. The only requirement is that all polynomials have the same number of evaluations (not necessarily the same degree).

The provided leaves array has one entry for each leaf, and each leaf is a vector of K polynomial evaluations, with K = number of batched polynomials.

Neither the outer array nor the inner arrays can be empty.

pub fn new(values: Vec<Vec<Scalar>>) -> Self

Constructs a Merkle tree from a matrix of polynomial evaluations.

The outer array of values contains one entry per committed polynomial, and each of the inner arrays represents the evaluations of a polynomial.

Therefore values has as many elements as the number of polynomials being committed and the length of the inner arrays must equal the size of the (extended) evaluation domain.

Note that the only difference between new and from_leaves is that the dimensions of the provided matrix are inverted.

Neither the outer array nor the inner arrays can be empty.

pub fn num_polys(&self) -> usize

Returns the number of polynomials stored in the tree.

Each leaf of the tree has this number of values.

pub fn num_leaves(&self) -> usize

Returns the number of leaves in the tree, corresponding to the size of the evaluation domain (always a power of 2).

pub fn root_hash(&self) -> Scalar

Returns the root hash of the Merkle tree.

pub fn leaf(&self, index: usize) -> &[Scalar]

Returns a reference to the i-th leaf.

Note that the leaf contains k elements, one for every committed polynomial.

pub fn query(&self, index: usize) -> LeafProof<H>

Returns a Merkle proof for the leaf at index.