pub struct Committer<H: Hash<Scalar>> { /* private fields */ }Expand description
Collects batches of polynomials and allows building a DEEP-FRI prover for them.
This works by building Merkle trees on the batched polynomials, one tree per batch, and
eventually handing everything over to a newly constructed Prover (see the commit method).
This two-stage Committer-Prover architecture allows getting Merkle roots for the proven polynomials before running the FRI folding argument and even before batching all polynomials, so that Fiat-Shamir challenges can be derived before any quotients are built.
Implementations
Sourceimpl<H: Hash<Scalar>> Committer<H>
impl<H: Hash<Scalar>> Committer<H>
Sourcepub fn new(
degree_bound: usize,
blowup_log2: usize,
polynomials: Vec<Polynomial>,
) -> Self
pub fn new( degree_bound: usize, blowup_log2: usize, polynomials: Vec<Polynomial>, ) -> Self
Constructs a Committer with the given degree bound, blowup factor, and first batch of
polynomials.
We require specifying the first batch because our DEEP-FRI protocol requires at least one committed polynomial to work.
Sourcepub fn degree_bound(&self) -> usize
pub fn degree_bound(&self) -> usize
Returns the proven degree bound.
Sourcepub fn extended_domain_size(&self) -> usize
pub fn extended_domain_size(&self) -> usize
Returns the size of the extended evaluation domain.
Sourcepub fn num_trees(&self) -> usize
pub fn num_trees(&self) -> usize
Returns the number of Merkle trees constructed so far, corresponding to the number of polynomial batches.
Sourcepub fn tree(&self, index: usize) -> &Tree<H>
pub fn tree(&self, index: usize) -> &Tree<H>
Returns the i-th Merkle tree. index must be less than num_trees().
Sourcepub fn root_hash(&self, index: usize) -> Scalar
pub fn root_hash(&self, index: usize) -> Scalar
Returns the root hash of the i-th Merkle tree. index must be less than num_trees().
This value can be used to derive Fiat-Shamir challenges.
Sourcepub fn add_batch(&mut self, polynomials: Vec<Polynomial>) -> usize
pub fn add_batch(&mut self, polynomials: Vec<Polynomial>) -> usize
Adds a batch of polynomials, returnin the index of the newly created batch.
The returned index can be used with the tree and root_hash methods to get the Merkle
tree and root hash for the batch, respectively.
REQUIRES: the degree of all specified polynomials must be strictly less than
degree_bound().
Sourcepub fn commit(self, points: BTreeSet<Scalar>) -> (Commitment, Prover<H>)
pub fn commit(self, points: BTreeSet<Scalar>) -> (Commitment, Prover<H>)
Consumes the Committer, calculates all DEEP quotients, and returns a polynomial
Commitment and a DEEP-FRI Prover.
points is the set of points to open in the Prover. The contained scalars are
(off-domain) X-coordinates; the corresponding Y-coordinates will be computed automatically
for every batched polynomial.