pub struct Prover<H: Hash<Scalar>> { /* private fields */ }Expand description
A DEEP-FRI prover.
Provers are constructed by Committer::commit(); see that method for details.
Implementations
Sourceimpl<H: Hash<Scalar>> Prover<H>
impl<H: Hash<Scalar>> Prover<H>
Sourcepub fn degree_bound(&self) -> usize
pub fn degree_bound(&self) -> usize
Returns the proven degree bound.
Sourcepub fn extended_domain_size(&self) -> usize
pub fn extended_domain_size(&self) -> usize
Returns the size of the extended evaluation domain.
Sourcepub fn num_trees(&self) -> usize
pub fn num_trees(&self) -> usize
Returns the number of Merkle trees, corresponding to the number of polynomial batches.
Sourcepub fn tree(&self, index: usize) -> &Tree<H>
pub fn tree(&self, index: usize) -> &Tree<H>
Returns the i-th Merkle tree. index must be less than num_trees().
Sourcepub fn root_hash(&self, index: usize) -> Scalar
pub fn root_hash(&self, index: usize) -> Scalar
Returns the root hash of the i-th Merkle tree. index must be less than num_trees().
This value can be used to derive Fiat-Shamir challenges.
Sourcepub fn points(&self) -> &BTreeMap<Scalar, Vec<Scalar>>
pub fn points(&self) -> &BTreeMap<Scalar, Vec<Scalar>>
Returns a reference to the opened points. Keys are (off-domain) X-coordinates, values are the corresponding evaluations (one for every committed polynomial).
Sourcepub fn prove(&self, commitment: &Commitment) -> Proof<H>
pub fn prove(&self, commitment: &Commitment) -> Proof<H>
Makes a DEEP-FRI proof opening the committed polynomials at the points specified at
commitment time (see Committer::commit()).